@@ -11,7 +11,7 @@ class MSDOSSwapPartition(MSDOSPartition):
         :param Bytes size: Size of the partition
         :param BasePartition previous: The partition that preceeds this one
         """
-        super(MSDOSSwapPartition, self).__init__(size, 'swap', None, previous)
+        super(MSDOSSwapPartition, self).__init__(size, 'swap', None, None, 'swap', previous)
 
     def _before_format(self, e):
         log_check_call(['mkswap', self.device_path])
