@@ -28,3 +28,11 @@ class Snapshot(Task):
     @classmethod
     def run(cls, info):
         info._ec2['snapshot'] = info.volume.snapshot()
+
+        # Setting up tags on the snapshot
+        if 'tags' in info.manifest.data:
+            raw_tags = info.manifest.data['tags']
+            formatted_tags = {k: v.format(**info.manifest_vars) for k, v in raw_tags.items()}
+            tags = [{'Key': k, 'Value': v} for k, v in formatted_tags.items()]
+            info._ec2['connection'].create_tags(Resources=[info._ec2['snapshot']],
+                                                Tags=tags)
