@@ -23,14 +23,21 @@ def test_identity():
 
 
 def test_not_identity():
-    assert releases.wheezy is not releases.stable
-    assert releases.stable is not releases.jessie
+    # "==" tests equality "is" tests identity
+    assert releases.stretch == releases.stable
+    assert releases.stretch is not releases.stable
+
+    assert releases.stable is releases.stable
+    assert releases.stretch is releases.stretch
+
+    assert releases.jessie != releases.stable
+    assert releases.jessie is not releases.stable
 
 
 def test_alias():
-    assert releases.oldstable == releases.wheezy
-    assert releases.stable == releases.jessie
-    assert releases.testing == releases.stretch
+    assert releases.oldstable == releases.jessie
+    assert releases.stable == releases.stretch
+    assert releases.testing == releases.buster
     assert releases.unstable == releases.sid
 
 
